Print results from fitting a spatially explicit capture--recapture model, or generate a list of summary data.
# S3 method for openCR
print (x, newdata = NULL, alpha = 0.05, svtol = 1e-5,...)
# S3 method for openCR
summary (object, newdata = NULL, alpha = 0.05, svtol = 1e-5, deriv = FALSE, ...)
The summary method constructs a list of outputs similar to those printed by the print method,
but somewhat more concise and re-usable:
| versiontime | secr version, and date and time fitting started |
| traps* | detector summary |
| capthist | capthist summary (primary and secondary sessions, numbers of animals and detections) |
| intervals | intervals between primary sessions |
| mask* | mask summary |
| modeldetails | miscellaneous model characteristics (type etc.) |
| AICtable | single-line output of AIC.openCR |
| coef | table of fitted coefficients with CI |
| predicted | predicted values (`real' parameter estimates) |
| derived | output of derived.openCR (optional) |
* spatial models only
openCR object output from openCR.fit
openCR object output from openCR.fit
optional dataframe of values at which to evaluate model
alpha level
threshold for non-null eigenvalues when computing numerical rank
logical; if TRUE then table of derived parameters is calculated
other arguments passed to derived.openCR by summary.openCR
Results are potentially complex and depend upon the analysis (see below). Optional newdata should be a dataframe with a column for each of the variables in the model. If newdata is missing then a dataframe is constructed automatically. Default newdata are for a naive animal on the first occasion; numeric covariates are set to zero and factor covariates to their base (first) level. Confidence intervals are 100 (1 -- alpha) % intervals.
| call | the function call |
| time | date and time fitting started |
| N animals | number of distinct animals detected |
| N captures | number of detections |
| N sessions | number of sampling occasions |
| Model | model formula for each `real' parameter |
| Fixed | fixed real parameters |
| N parameters | number of parameters estimated |
| Log likelihood | log likelihood |
| AIC | Akaike's information criterion |
| AICc | AIC with small sample adjustment (Burnham and Anderson 2002) |
| Beta parameters | coef of the fitted model, SE and confidence intervals |
| Eigenvalues | scaled eigenvalues of Hessian matrix (maximum 1.0) |
| Numerical rank | number of eigenvalues exceeding svtol |
| vcov | variance-covariance matrix of beta parameters |
| Real parameters | fitted (real) parameters evaluated at base levels of covariates |
AICc is computed with the default sample size (number of individuals) and parameter count (use.rank = FALSE).
Burnham, K. P. and Anderson, D. R. (2002) Model selection and multimodel inference: a practical information-theoretic approach. Second edition. New York: Springer-Verlag.
AIC.openCR, openCR.fit
if (FALSE) {
c1 <- openCR.fit(ovenCH, type='CJS', model=phi~session)
c1
}
Run the code above in your browser using DataLab